==> react-query-lightbase-codegen-1.0.0.tgz: package/lib/esm/importSpecs.js <==
import chalk from 'chalk';
import { readFileSync, writeFileSync, readdir, mkdirSync } from 'fs';
import { join, parse } from 'path';
import { convertSwaggerFile } from './convertSwaggerFile.js';
import { createHook } from './generateHooks.js';
import { generateImports } from './generateImports.js';
import { generateSchemas } from './generateSchemas.js';
export function importSpecs({ sourceDirectory, exportDirectory, apiDirectory, queryClientDir, headerFilters, overrides, }) {
    readdir(sourceDirectory, function (err, filenames) {
        if (err) {
            console.log(err);
            throw err;
        }
        filenames.map(async (filename) => {
            try {
                const data = readFileSync(join(process.cwd(), sourceDirectory + '/' + filename), 'utf-8');
                const { ext } = parse(sourceDirectory + '/' + filename);
                const format = ['.yaml', '.yml'].includes(ext.toLowerCase()) ? 'yaml' : 'json';
                let spec = await convertSwaggerFile(data, format);
                const schemaName = `useQueries${filename.split('.')[0]}.schema`;
                const hooksName = `useQueries${filename.split('.')[0]}`;
                const name = filename.split('.')[0];
                mkdirSync(join(process.cwd(), `${exportDirectory}/${name}`), { recursive: true });
                const operationIds = [];
                let hooks = '';
                let schemaImportsArray = [];
                let collectedQueryImports = [];
                Object.entries(spec.paths).forEach(([route, verbs]) => {
                    Object.entries(verbs).forEach(([verb, operation]) => {
                        if (['get', 'post', 'patch', 'put', 'delete'].includes(verb) && !operation.deprecated) {
                            const { implementation, imports, queryImports } = createHook({
                                operation,
                                verb,
                                route: (spec.basePath || '') + route,
                                operationIds,
                                parameters: verbs.parameters,
                                schemasComponents: spec.components,
                                headerFilters,
                                overrides,
                            });
                            hooks += implementation;
                            imports.forEach((element) => {
                                const formattedImport = element.replace('[]', '');
                                if (!schemaImportsArray.includes(formattedImport) &&
                                    element !== 'void' &&
                                    element !== 'string' &&
                                    !element.includes('{')) {
                                    schemaImportsArray.push(formattedImport);
                                }
                            });
                            queryImports.forEach((element) => {
                                if (!schemaImportsArray.includes(element)) {
                                    collectedQueryImports.push(element);
                                }
                            });
                        }
                    });
                });
                const imports = generateImports({
                    apiDirectory,
                    queryClientDir,
                    schemaName,
                    schemaImports: schemaImportsArray,
                    queryImports: collectedQueryImports,
                });
                writeFileSync(join(process.cwd(), `${exportDirectory}/${name}/${hooksName}.tsx`), imports + hooks);
                const schemas = generateSchemas({ spec });
                writeFileSync(join(process.cwd(), `${exportDirectory}/${name}/${schemaName}.tsx`), schemas);
                console.log(chalk.green(`🎉 [${filename}] Your OpenAPI spec has been converted into react query hooks`));
            }
            catch (error) {
                if (error.code === 'EISDIR') {
                    console.log(chalk.red('nested folder structure not supported'));
                    return;
                }
                console.log(chalk.red(`[${filename}]:`), chalk.red(error));
            }
        });
    });
}

==> react-query-lightbase-codegen-1.1.1.tgz: package/lib/esm/importSpecs.js <==
import chalk from 'chalk';
import { readFileSync, writeFileSync, readdir, mkdirSync } from 'fs';
import { join, parse } from 'path';
import { convertSwaggerFile } from './convertSwaggerFile.js';
import { generateImports, generateQueryHooks } from './generateHooks.js';
import { generateSchemas } from './generateSchemas.js';
export function importSpecs({ sourceDirectory, exportDirectory, apiDirectory, queryClientDir, headerFilters, }) {
    readdir(sourceDirectory, function (err, filenames) {
        if (err) {
            console.log(err);
            throw err;
        }
        filenames.map(async (filename) => {
            try {
                const data = readFileSync(join(process.cwd(), sourceDirectory + '/' + filename), 'utf-8');
                const { ext } = parse(sourceDirectory + '/' + filename);
                const format = ['.yaml', '.yml'].includes(ext.toLowerCase()) ? 'yaml' : 'json';
                const name = filename.split('.')[0];
                let spec = await convertSwaggerFile(data, format);
                const operationIds = [];
                mkdirSync(join(process.cwd(), `${exportDirectory}/${name}`), { recursive: true });
                const { implementation, schemaImports } = generateQueryHooks({ spec, operationIds, headerFilters });
                const schemaName = `useQueries${filename.split('.')[0]}.schema`;
                const imports = generateImports({ apiDirectory, queryClientDir, schemaName, schemaImports });
                const hooksName = `useQueries${filename.split('.')[0]}`;
                writeFileSync(join(process.cwd(), `${exportDirectory}/${name}/${hooksName}.tsx`), imports + implementation);
                const schemas = generateSchemas({ spec });
                writeFileSync(join(process.cwd(), `${exportDirectory}/${name}/${schemaName}.tsx`), schemas);
                console.log(chalk.green(`🎉 [${filename}] Your OpenAPI spec has been converted into react query hooks`));
            }
            catch (error) {
                if (error.code === 'EISDIR') {
                    return;
                }
                console.log(chalk.red(`[${filename}]:`), chalk.red(error));
            }
        });
    });
}
